@@ -1,5 +1,4 @@
-from fcp.fcp_lib import Fcp
-from fcp.spec import Spec
+from .specs import Spec
 
 from .fcp_lib import *
 from .can import CANMessage
